# Test TimeTextBox Widget

Time using local conventions with seconds TimeTextBox class, Attributes: {formatLength:'medium'}
onChange:
Time using local conventions without seconds, required, no invalid message tooltip TimeTextBox class, Attributes: {formatLength:'short'}
12 Hour Time TimeTextBox class, Attributes: {timePattern:'h:mm:ss a'}
24 Hour Time TimeTextBox class, Attributes: {timePattern:'HH:mm:ss'}
Initially empty time text box TimeTextBox class, Attributes: {formatLength:'medium',min:'T00:00:00',max:'T12:00:00'}
onChange:
Using title attribute for label. TimeTextBox class, Attributes: {formatLength:'short'} Time using local conventions without seconds, required, no invalid message tooltip
Ticket #18201 Ensure that Date values can used with TimeTextBoxes
TimeTextBox with dropdown from 9AM - 5PM TimeTextBox class, Attributes: {formatLength:"medium", pickerMin: "T09:00:00", clickableIncrement: "T01:00:00", pickerMax: "T17:00:00"}
onChange: